diff --git a/arch/arm/mach-omap2/omap5/hw_data.c b/arch/arm/mach-omap2/omap5/hw_data.c
index 15e52aa..27fa985 100644
--- a/arch/arm/mach-omap2/omap5/hw_data.c
+++ b/arch/arm/mach-omap2/omap5/hw_data.c
@@ -8,6 +8,7 @@
  *
  * Sricharan R <r.sricharan@ti.com>
  */
+
 #include <common.h>
 #include <palmas.h>
 #include <asm/arch/omap.h>
@@ -17,6 +18,7 @@
 #include <asm/omap_gpio.h>
 #include <asm/io.h>
 #include <asm/emif.h>
+#include <asm/ti-common/ti-edma3.h>
 
 struct prcm_regs const **prcm =
 			(struct prcm_regs const **) OMAP_SRAM_SCRATCH_PRCM_PTR;
@@ -515,11 +517,37 @@ void enable_basic_clocks(void)
 			OPTFCLKEN_SCRM_CORE_MASK);
 }
 
+#if defined(CONFIG_DRA7XX)
+static void do_edma3_copy_mmap(void *data, void *offset, size_t len)
+{
+	unsigned int			addr = (unsigned int) (data);
+	unsigned int			edma_slot_num = 1;
+
+	/* Invalidate the area, so no writeback into the RAM races with DMA */
+	invalidate_dcache_range(addr, addr + roundup(len, ARCH_DMA_MINALIGN));
+
+	/* enable edma3 clocks */
+	enable_edma3_clocks();
+
+	/* Call edma3 api to do actual DMA transfer	*/
+	edma3_transfer(EDMA3_BASE, edma_slot_num, data, offset, len);
+
+	/* disable edma3 clocks */
+	disable_edma3_clocks();
+
+	*((unsigned int *)offset) += len;
+}
+#endif
+
 #if defined(CONFIG_DRA7XX)
 void do_enable_pruss_clocks(void)
 {
-	out_le32(0x4a009718, MODULE_CLKCTRL_MODULEMODE_SW_EXPLICIT_EN);
-	out_le32(0x4a009720, MODULE_CLKCTRL_MODULEMODE_SW_EXPLICIT_EN);
+	unsigned int *address = (unsigned int *) 0x4A009718;
+
+	unsigned int data[4] = {0x2,0x0,0x2,0x0};
+
+	do_edma3_copy_mmap(address,data,16);
+
 }
 #endif
 
